summaryrefslogtreecommitdiff
path: root/paste/wsgiwrappers.py
diff options
context:
space:
mode:
authorpjenvey <devnull@localhost>2006-07-25 22:22:52 +0000
committerpjenvey <devnull@localhost>2006-07-25 22:22:52 +0000
commit2609e41126e646e5339a0f48c26e366adf98b06e (patch)
tree5175cfa0bd3f9e9c2aac987644524aac2654c10f /paste/wsgiwrappers.py
parent6ac1b315d366733f2b43956696a2efbd6e2f00ef (diff)
downloadpaste-2609e41126e646e5339a0f48c26e366adf98b06e.tar.gz
renamed the multidict class to MultiDict
Diffstat (limited to 'paste/wsgiwrappers.py')
-rw-r--r--paste/wsgiwrappers.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/paste/wsgiwrappers.py b/paste/wsgiwrappers.py
index e471aef..84a0924 100644
--- a/paste/wsgiwrappers.py
+++ b/paste/wsgiwrappers.py
@@ -2,7 +2,7 @@
# Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.php
import paste.httpexceptions
from paste.request import EnvironHeaders, parse_formvars, parse_dict_querystring, get_cookie_dict
-from paste.util.multidict import multidict
+from paste.util.multidict import MultiDict
from paste.response import HeaderDict
import paste.registry as registry
import paste.httpexceptions
@@ -89,7 +89,7 @@ class WSGIRequest(object):
POST = property(POST, doc=POST.__doc__)
def params(self):
"""multidict of keys from POST, GET, URL dicts
Return a key value from the parameters, they are checked in the
following order: POST, GET, URL
@@ -100,7 +100,7 @@ class WSGIRequest(object):
Returns a list of all the values by that key, collected from
POST, GET, URL dicts
"""
- pms = multidict()
+ pms = MultiDict()
pms.update(self.POST)
pms.update(self.GET)
return pms
@@ -89,7 +89,7 @@ class WSGIRequest(object):
POST = property(POST, doc=POST.__doc__)
def params(self):
- """multidict of keys from POST, GET, URL dicts
+ """MultiDict of keys from POST, GET, URL dicts
Return a key value from the parameters, they are checked in the
following order: POST, GET, URL